mq: deprecate qsave, qrestore and related options
authorDirkjan Ochtman <djc.ochtman@kentyde.com>
Sun, 07 Feb 2010 12:34:02 +0100
changeset 10360 bcf90e712dc3
parent 10359 ec02cf8d1628
child 10361 49cd2e7fd91c
mq: deprecate qsave, qrestore and related options
hgext/mq.py
tests/test-mq.out
--- a/tests/test-mq.out	Tue Dec 23 09:46:40 2008 -0800
+++ b/tests/test-mq.out	Sun Feb 07 12:34:02 2010 +0100
@@ -54,8 +54,6 @@
  qpush        push the next patch onto the stack
  qrefresh     update the current patch
  qrename      rename a patch
- qrestore     restore the queue state saved by a revision
- qsave        save current queue state
  qselect      set or print guarded patches to push
  qseries      print the entire series file
  qtop         print the name of the current patch
--- a/hgext/mq.py	Tue Dec 23 09:46:40 2008 -0800
+++ b/hgext/mq.py	Sun Feb 07 12:34:02 2010 +0100
@@ -2316,7 +2316,9 @@
     q.save_dirty()
 
 def restore(ui, repo, rev, **opts):
-    """restore the queue state saved by a revision"""
+    """restore the queue state saved by a revision (DEPRECATED)
+
+    This command is deprecated, use rebase --mq instead."""
     rev = repo.lookup(rev)
     q = repo.mq
     q.restore(repo, rev, delete=opts['delete'],
@@ -2325,7 +2327,9 @@
     return 0
 
 def save(ui, repo, **opts):
-    """save current queue state"""
+    """save current queue state (DEPRECATED)
+
+    This command is deprecated, use rebase --mq instead."""
     q = repo.mq
     message = cmdutil.logmessage(opts)
     ret = q.save(repo, msg=message)
@@ -2704,7 +2708,7 @@
     "^qpop":
         (pop,
          [('a', 'all', None, _('pop all patches')),
-          ('n', 'name', '', _('queue name to pop')),
+          ('n', 'name', '', _('queue name to pop (DEPRECATED)')),
           ('f', 'force', None, _('forget any local changes to patched files'))],
          _('hg qpop [-a] [-n NAME] [-f] [PATCH | INDEX]')),
     "^qpush":
@@ -2712,8 +2716,8 @@
          [('f', 'force', None, _('apply if the patch has rejects')),
           ('l', 'list', None, _('list patch name in commit text')),
           ('a', 'all', None, _('apply all patches')),
-          ('m', 'merge', None, _('merge from another queue')),
-          ('n', 'name', '', _('merge queue name'))],
+          ('m', 'merge', None, _('merge from another queue (DEPRECATED)')),
+          ('n', 'name', '', _('merge queue name (DEPRECATED)'))],
          _('hg qpush [-f] [-l] [-a] [-m] [-n NAME] [PATCH | INDEX]')),
     "^qrefresh":
         (refresh,